@@ -7,8 +7,8 @@ from ogoutils.decryption import decryption
 
 pwd = Path.cwd()
 
-file_path = str(pwd / 'diary')
-crp_file_path = str(pwd / 'diary.crp')
+file_path = pwd / 'diary'
+crp_file_path = pwd / 'diary.crp'
 
 
 def read_diary():
@@ -28,7 +28,7 @@ def write_diary():
     """ Write your thoughts into the diary file """
     password = input('Введите пароль: ')
 
-    is_diary_exists = os.path.isfile(crp_file_path)
+    is_diary_exists = os.path.isfile(crp_file_path.is_file())
 
     if is_diary_exists:
         res = decryption(file=crp_file_path, password=password)
